<?php
// Adding functions for theme

if (!function_exists('getSolidColorFromImage')) {
    function getSolidColorFromImage($filepath) { 
        $attach_id = get_post_thumbnail_id(get_the_ID());
        $solid_color = get_post_meta( $attach_id, 'solid_color', true);

        if (!empty($solid_color)) {
            return $solid_color;
        }
            
        $type = wp_check_filetype($filepath); // [] if you don't have exif you could use getImageSize() 
        if (!empty($type) && is_array($type) && !empty($type['ext'])) {
            $type = $type['ext'];
        }else{
            return '#D3D3D3';
        }
        $allowedTypes = array( 
            'gif',  // [] gif 
            'jpg',  // [] jpg 
            'png',  // [] png 
            'bmp'   // [] bmp 
        ); 
        if (!in_array($type, $allowedTypes)) { 
            return '#D3D3D3';
        } 
        $im = false;
        switch ($type) { 
            case 'gif' : 
                $im = imageCreateFromGif($filepath); 
            break; 
            case 'jpg' : 
                $im = imageCreateFromJpeg($filepath); 
            break; 
            case 'png' : 
                $im = imageCreateFromPng($filepath); 
            break; 
            case 'bmp' : 
                $im = imageCreateFromBmp($filepath); 
            break; 
        } 

        if ($im) {
            $thumb=imagecreatetruecolor(1,1); 
            imagecopyresampled($thumb,$im,0,0,0,0,1,1,imagesx($im),imagesy($im));
            $mainColor=strtoupper(dechex(imagecolorat($thumb,0,0)));
            update_post_meta( $attach_id, 'solid_color', $mainColor );
            return $mainColor;
        }else{
            return '#D3D3D3';
        }

          
    }
}  

if (!function_exists('exif_imagetype')) {
    function exif_imagetype($filename){
        $img = getimagesize( $filename );
        if ( !empty( $img[2] ) )
          return  $img[2];
        return false;
    }
}

// srcset maker 
if (!function_exists('oswald_get_image_srcset')) {
    /**
     *  get image src,srcset,sizes
     * @param  [type]  $src                   [image src]
     * @param  integer $image_ratio           [ratio of width/height]
     * @param  array   $responsive_dimensions [array with demensions settings arrays]
     * @return [type]                         [src srcset sizes html]
     */
    function oswald_get_image_srcset($src,$image_ratio = 1,$responsive_dimensions = array()){
        if (empty($src)) {
            return;
        }

        $srcset_out = '';
        $sizes_out  = '';
        $image_width_and_dimensions = array();
        $src_out = '';

        $image_width_array = array();

        if (!empty($responsive_dimensions)) {
            foreach ($responsive_dimensions as $responsive_dimension) {
                $view_port = $responsive_dimension[0];
                $image_width = $responsive_dimension[1];
                $responsive_image_ratio = !empty($responsive_dimension[2]) ? $responsive_dimension[2] : $image_ratio;
                if ($responsive_image_ratio == null) {
                    $image_height = null;
                }else{
                   $image_height = (int)($image_width * $responsive_image_ratio);  
                } 

                $image_width_array[$image_width] = true;               

                if (!empty($view_port)) {
                    if (!empty($sizes_out)) {
                        $sizes_out .= ', ';
                    }
                    $sizes_out .= '(min-width: '.(int)$view_port.'px) '.(int)$image_width.'px';
                    if ((int)$view_port == 1200) {
                        $src_out = 'src="'.esc_url(aq_resize($src, $image_width, $image_height, true, true, true )).'"';
                    }
                }             

                if (empty($image_width_and_dimensions[$image_width.'_'.$image_height])) {
                    $image_width_and_dimensions[$image_width.'_'.$image_height] = true;  
                    $srcset_out .= !empty($srcset_out) ? ', ' : '';
                    $srcset_out .= esc_url(aq_resize($src, $image_width, $image_height, true, true, true ));
                    $srcset_out .= ' '.(int)$image_width.'w';
                }                 

            }
            if ( empty($image_width_array['420'])) {
                $sizes_out .= ', (max-width: 600px) 420px';
                $srcset_out .= ','.esc_url(aq_resize($src, 420, 420*$image_ratio, true, true, true )).' 420w';
            }
        }
        if (empty($src_out)) {            
            $src_out = 'src="'.esc_url(aq_resize($src, 1170, 1170*$image_ratio, true, true, true )).'"';
        }

        if (!empty($srcset_out)) {
            $srcset_out = ' srcset="'.$srcset_out.'"';
        }

        if (!empty($sizes_out)) {
            $sizes_out = ' sizes="'.$sizes_out.'"';
        }

        return $src_out.$srcset_out.$sizes_out;

    }
}
if (!function_exists('oswald_add_like')) {
    add_action( 'wp_ajax_add_like_attachment', 'oswald_add_like' );
    add_action( 'wp_ajax_nopriv_add_like_attachment', 'oswald_add_like' );
    function oswald_add_like() {
        $all_likes = oswald_get_option("likes");
        $attach_id = absint($_POST['attach_id']);
        $all_likes[$attach_id] = (isset($all_likes[$attach_id]) ? $all_likes[$attach_id] : 0)+1;
        oswald_update_option("likes", $all_likes);
        echo absint($all_likes[$attach_id]);
        die();
    }
}


if (!function_exists('oswald_post_likes')) {
    function oswald_post_likes(){
        $all_likes = oswald_get_option("likes");
        wp_enqueue_script('jquery.cookie');
        if (isset($all_likes[get_the_ID()]) && $all_likes[get_the_ID()] == 1) {
            $likes_text_label = esc_html__('Like', 'wpdaddy_core');
        } else {
            $likes_text_label = esc_html__('Likes', 'wpdaddy_core');
        }
        ?>
        <div class="wpd_blog_list__post_likes likes_block post_likes_add<?php echo isset($_COOKIE['like_post'.get_the_ID()]) ? ' already_liked' : ''; ?>" data-postid="<?php echo esc_attr(get_the_ID()); ?>"  data-modify="like_post" title="<?php echo (isset($all_likes[get_the_ID()]) ? $all_likes[get_the_ID()] : 0 ). ' ' . $likes_text_label; ?>">
            <span class="wpd_post_likes__icon fa fa-heart-o"></span>
            <span class="wpd_post_likes__value like_count"><?php echo ((isset($all_likes[get_the_ID()]) && $all_likes[get_the_ID()]>0) ? $all_likes[get_the_ID()] : 0);?></span>
        </div><?php
    }
}

if (!function_exists('oswald_post_share')) {
    function oswald_post_share(){
        ?><div class="wpd_blog_list__share">
            <a href="#"><?php esc_html_e('Share', 'wpdaddy_core'); ?></a>
            <div class="share_wrap">
                <ul>
                    <li><a target="_blank" href="<?php echo esc_url('https://twitter.com/intent/tweet?text='. get_the_title() .'&amp;url='. get_permalink()); ?>"><span class="fa fa-twitter"></span></a></li>
                    <li><a target="_blank" href="<?php echo esc_url('https://www.facebook.com/share.php?u='. get_permalink()); ?>"><span class="fa fa-facebook"></span></a></li>
                    <li><a target="_blank" href="<?php echo 'https://plus.google.com/share?url='.urlencode(get_permalink()); ?>" class="share_gplus"><span class="fa fa-google-plus"></span></a></li>
                    <?php if (has_post_thumbnail()) { ?>
                        <li><a target="_blank" href="<?php echo esc_url('https://pinterest.com/pin/create/button/?url=' . get_permalink() .'&media='. get_the_post_thumbnail());?>"><span class="fa fa-pinterest"></span></a></li>
                    <?php } ?>
                </ul>
            </div>
        </div><?php
    }
}

if (!function_exists('oswald_admin_theme_scripts')) {
    function oswald_admin_theme_scripts(){
        $template_directory_uri = get_template_directory_uri();
        // colorpicker
        wp_enqueue_script( 'wp-color-picker' );
        wp_enqueue_style( 'wp-color-picker' );

        wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', array(), '4.7.0', 'all' );
        wp_enqueue_style('admin_css', $template_directory_uri . '/assets/admin/css/admin.css');
        if (class_exists( 'RWMB_Loader' )) {
            wp_enqueue_script('metaboxes_js', $template_directory_uri . '/assets/admin/js/metaboxes.js');
        }
        wp_enqueue_script('oswald_theme_admin_js', $template_directory_uri . '/assets/admin/js/admin.js', array('jquery'), false, true);
    }
}


//* Tiny mce adding *//
if (!function_exists('oswald_mce_buttons')) {
    function oswald_mce_buttons() {
        if (current_user_can('edit_posts') && current_user_can('edit_pages')) {
            add_filter( 'mce_external_plugins', 'oswald_add_external_plugins' );
            add_filter('mce_buttons_3', 'oswald_mce_buttons_register_button');
            add_filter( 'mce_buttons_2', 'oswald_mce_buttons_2' );
        }
    }
    add_action('init', 'oswald_mce_buttons');
}

if (!function_exists('oswald_add_external_plugins')) {
    function oswald_add_external_plugins(){
        $plugin_array['oswald_external_tinymce_plugins'] = get_template_directory_uri() . '/assets/admin/js/tinymce-button.js';
        return $plugin_array;
    }
}

if (!function_exists('oswald_mce_buttons_register_button')) {
    function oswald_mce_buttons_register_button( $buttons ) {
        array_push( $buttons, 'SocialIcon','DropCaps', 'Highlighter', 'SecondaryFont', 'LinkStyling', 'ListStyle', 'Columns' );
        return $buttons;
    }
}

if (!function_exists('oswald_mce_buttons_2')) {
    function oswald_mce_buttons_2( $buttons ) {
        array_unshift( $buttons, 'styleselect' );
        return $buttons;
    }
}


if (!function_exists('oswald_tiny_mce_before_init')) {
    function oswald_tiny_mce_before_init( $settings ) {
        $settings['theme_advanced_blockformats'] = 'p,h1,h2,h3,h4';
        $style_formats = array(
            array( 'title' => esc_html__( 'Font Weight', 'oswald_lite_extension' ), 'items' => array(
                array( 'title' => esc_html__( 'Default', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => 'inherit' ) ),
                array( 'title' => esc_html__( 'Lightest (100)', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => '100' ) ),
                array( 'title' => esc_html__( 'Lighter (200)', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => '200' ) ),
                array( 'title' => esc_html__( 'Light (300)', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => '300' ) ),
                array( 'title' => esc_html__( 'Normal (400)', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => '400' ) ),
                array( 'title' => esc_html__( 'Medium (500)', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => '500' ) ),
                array( 'title' => esc_html__( 'Semi-Bold (600)', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => '600' ) ),
                array( 'title' => esc_html__( 'Bold (700)', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => '700' ) ),
                array( 'title' => esc_html__( 'Bolder (800)', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => '800' ) ),
                array( 'title' => esc_html__( 'Extra Bold (900)', 'oswald_lite_extension' ), 'inline' => 'span', 'classes' => 'wpd_font-weight', 'styles' => array( 'font-weight' => '900' ) ),
                )
            ),
        );

        $settings['style_formats'] = str_replace( '"', "'", json_encode( $style_formats ) );
        $settings['extended_valid_elements'] = 'span[*],a[*],i[*]';
        return $settings;
    }
    add_filter( 'tiny_mce_before_init', 'oswald_tiny_mce_before_init' );
}

if (!function_exists('oswald_theme_add_editor_styles')) {
    function oswald_theme_add_editor_styles() {
        add_editor_style( 'assets/css/font-awesome.min.css' );
        add_editor_style( 'assets/css/tiny_mce.css' );
    }
    add_action( 'current_screen', 'oswald_theme_add_editor_styles' );
}
//* End Tiny mce adding *//


// styling add 
if (!function_exists('oswald_lite_setup_theme')) {
    function oswald_lite_setup_theme() {
        if (function_exists('oswald_admin_theme_scripts')) {
            add_action('admin_enqueue_scripts', 'oswald_admin_theme_scripts'); 
        } 
    }
    add_action('after_setup_theme', 'oswald_lite_setup_theme'); 
}

if (!function_exists('oswald_extend_def_option')) {
    function oswald_extend_def_option(){
        $oswald_option = get_option( 'oswald' );

        if (!isset($oswald_option['homepage_header_image'])) {
            $customizer_def_option = array(
                'homepage_header_image' => 'https://themes.wpdaddy.com/oswald-lite/wp-content/uploads/sites/7/2018/08/header_1.jpg',
                'homepage_header_pre_title' => 'You Should Know About',
                'homepage_header_title' => 'Our Startup',
                'homepage_header_text' => 'We get up in the morning because we love what we do, making beautiful designs come to life while helping people like you',
                'homepage_header_button_label_1' => 'Get Started',
                'homepage_header_button_link_1' => '#',
                'homepage_header_button_bg_color_1' => '#f75757',
                'homepage_header_button_label_2' => 'Learn More',
                'homepage_header_button_link_2' => '#',
                'homepage_header_button_bg_color_2' => '#f75757',
                'about_image' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/03/about_3.jpg',
                'about_pre_title' => 'Video presentations about us',
                'about_title' => 'Hey, We are Oswald',
                'about_text' => 'Our approach is simple. From the first stages of inception of a project, through its final stages of delivery and beyond, we aim to couple our big design agency professionalism and capabilities with the friendliness and flexibility. We take the time to get to know our clients, so that we can effectively unite their business objectives with intelligent creative digital design solutions',
                'about_button_label' => 'Get Started',
                'about_button_link' => '#',
                'about_button_bg_color' => '#f75757',
                'about_button_color' => '#ffffff',
                'call_to_action_bg_image' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/03/home_2_5.jpg',
                'call_to_action_title' => 'Got an Incredible Project?',
                'call_to_action_text' => 'Lets collaborate and make an impact with our cross-discipline approach to design and development',
                'call_to_action_button_label' => 'Get in Touch',
                'call_to_action_button_link' => '#',
                'call_to_action_button_bg_color' => '#f75757',
                'call_to_action_button_color' => '#ffffff',
                'services_pre_title' => 'All the services you ll need',
                'services_title' => 'Enjoy Our Best Services',
                'services_text' => 'We take the time to get to know our clients, so that we can effectively unite their business objectives with intelligent creative digital design solutions. That means that all of our clients can enjoy the benefits of a project that has been tailored to their exact needs',
                'service_image_1' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/03/coding.png',
                'service_title_1' => 'DEVELOPMENT',
                'service_text_1' => 'Designing and building business critical web apps and responsive websites is our true passion',
                'service_image_2' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/03/idea.png',
                'service_title_2' => 'MARKETING',
                'service_text_2' => 'Whether you are an established business or a startup, ensuring you have a well digital marketing',
                'service_image_3' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/03/design.png',
                'service_title_3' => 'BRANDING',
                'service_text_3' => 'Through research and exploration, we will design a memorable brand that you will be proud of',
                'service_image_4' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/03/icon_team.png',
                'service_title_4' => 'EXPERIENCE',
                'service_text_4' => 'Get you hands-on experience working on teams and projects. Let you meet and network with our developers',
                'service_image_5' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/03/icon_puzzle.png',
                'service_title_5' => 'RESPONSIBILITY',
                'service_text_5' => 'The state or fact of having a duty to deal with something or of having control over someone',
                'service_image_6' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/03/icon_support.png',
                'service_title_6' => 'STRATEGY',
                'service_text_6' => 'Strategy involves goals, determining actions to achieve the goals, and mobilizing resources',
                'team_pre_title' => 'Who we are',
                'team_title' => 'Meet Our Team',
                'team_text' => 'We are always looking for great, creative people to join our team, regardless of our current opportunities. Get in touch, and we ll be happy to chat. Designing and building business critical web apps and responsive websites is our true passion.',
                'team_image_1' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/team-2-370x370.jpg',
                'team_title_1' => 'Henry Oswald',
                'team_position_1' => 'Founder',
                'team_social_1' => '<a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#3b5998"><i class="fa fa-facebook"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#55acee"><i class="fa fa-twitter"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#df4b38"><i class="fa fa-google-plus"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#0084bf"><i class="fa fa-linkedin-square"></i></a>',
                'team_social_2' => '<a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#3b5998"><i class="fa fa-facebook"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#55acee"><i class="fa fa-twitter"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#df4b38"><i class="fa fa-google-plus"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#0084bf"><i class="fa fa-linkedin-square"></i></a>',
                'team_social_3' => '<a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#3b5998"><i class="fa fa-facebook"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#55acee"><i class="fa fa-twitter"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#df4b38"><i class="fa fa-google-plus"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#0084bf"><i class="fa fa-linkedin-square"></i></a>',
                'team_social_4' => '<a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#3b5998"><i class="fa fa-facebook"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#55acee"><i class="fa fa-twitter"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#df4b38"><i class="fa fa-google-plus"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#0084bf"><i class="fa fa-linkedin-square"></i></a>',
                'team_social_5' => '<a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#3b5998"><i class="fa fa-facebook"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#55acee"><i class="fa fa-twitter"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#df4b38"><i class="fa fa-google-plus"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#0084bf"><i class="fa fa-linkedin-square"></i></a>',
                'team_social_6' => '<a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#3b5998"><i class="fa fa-facebook"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#55acee"><i class="fa fa-twitter"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#df4b38"><i class="fa fa-google-plus"></i></a><a class="wpd_icon_link wpd_custom_color" style="font-size: 14px; color: inherit; margin-right: 15px; margin-top: 5px;" href="#" target="_blank" rel="noopener" data-hover-color="#0084bf"><i class="fa fa-linkedin-square"></i></a>',
                'team_image_2' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/team-1-370x370.jpg',
                'team_title_2' => 'David Spencer',
                'team_position_2' => 'Web Developer',
                'team_image_3' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/team-5-370x370.jpg',
                'team_title_3' => 'Samanta Damon',
                'team_position_3' => 'Project Manager',
                'team_image_4' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/team-4-370x370.jpg',
                'team_title_4' => 'Peter Odin',
                'team_position_4' => 'Attorney/Lawyer',
                'team_image_5' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/team-3-370x370.jpg',
                'team_title_5' => 'Mary Olson',
                'team_position_5' => 'Web Developer',
                'team_image_6' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/team-6-370x370.jpg',
                'team_title_6' => 'David Williams',
                'team_position_6' => 'Graphic Designer',
                'testimonial_pre_title' => 'Couple of worlds our clients',
                'testimonial_title' => 'What Our Customers Have to Say',
                'testimonial_image_1' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/tesimonials_1-80x80.jpg',
                'testimonial_name_1' => 'Celia Fields',
                'testimonial_position_1' => 'UX Expert',
                'testimonial_text_1' => 'We take the time to get to know our clients, so that we can effectively unite their business objectives with intelligent creative digital design solutions. That means that all of our clients can enjoy the benefits of a project that has been tailored to their exact needs',
                'testimonial_image_2' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/tesimonials_2-80x80.jpg',
                'testimonial_name_2' => 'Alexander Lee',
                'testimonial_position_2' => 'Founder',
                'testimonial_text_2' => 'We take the time to get to know our clients, so that we can effectively unite their business objectives with intelligent creative digital design solutions. That means that all of our clients can enjoy the benefits of a project that has been tailored to their exact needs',
                'homepage_blog_pre_title' => 'Latest news for you',
                'homepage_blog_title' => 'Read Our Blog',
                'homepage_blog_text' => 'Vestibulum accumsan convallis massa vitae pretium. Integer viverra quis tortor nec cursus. Morbi faucibus, ipsum vel scelerisque scelerisque, enim mi auctor nibh, quis feugiat.',
                'partners_image_1' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/Opscode_logo.png',
                'partners_link_1' => '#',
                'partners_image_2' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/logo-reuters.png',
                'partners_link_2' => '#',
                'partners_image_3' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/Strategy-Engine-Final-Colors-PNG.png',
                'partners_link_3' => '#',
                'partners_image_4' => 'https://themes.wpdaddy.com/oswald/wp-content/uploads/sites/4/2018/02/AVIS.png',
                'partners_link_4' => '#',
                'contact_pre_title_left' => 'Our contacts',
                'contact_title_left' => 'Get in Touch',
                'contact_text_left'  => '<h5><strong>ADDRESS</strong></h5>
    <p>455 Wallstreet St., New York, VA 12364, USA</p>
    <h5><strong>PHONES</strong></h5>
    <div><a class="wpd_styled_link wpd_custom_color" style="color: #3a405b;" href="tel:1-800-256-1234" data-color="#3a405b" data-hover-color="#222328">1-800-256-1234</a></div>
    <div><a class="wpd_styled_link wpd_custom_color" style="color: #3a405b;" href="tel:1-800-327-1235" data-color="#3a405b" data-hover-color="#222328">1-800-327-1235</a></div>
    <p><p>
    <h5><strong>E-MAIL</strong></h5>
    <p><a class="wpd_styled_link wpd_custom_color" style="color: #3a405b;" href="mailto:oswald@yoursite.com" data-color="#3a405b" data-hover-color="#222328">oswald@yoursite.com</a></p>
    <p><a class="wpd_styled_link wpd_custom_color wpd_styled_link__underline_on_hover" style="color: #3b5998;" href="#" data-color="#3b5998">Facebook</a><a class="wpd_styled_link wpd_custom_color wpd_styled_link__underline_on_hover" style="color: #55acee;" href="#" data-color="#55acee">Twitter</a><a class="wpd_styled_link wpd_custom_color wpd_styled_link__underline_on_hover" style="color: #df4b38;" href="#" data-color="#df4b38">Google+</a></p>',
                'contact_pre_title_right' => 'Send a message',
                'contact_title_right' => 'Contact Form',
                'contact_text_right' => '',
            );
            
            $standard_options = get_option( 'oswald_default_options' );

            $oswald_option = array_merge($oswald_option, $customizer_def_option);
            $standard_options = array_merge($standard_options, $customizer_def_option);
            update_option( 'oswald', $oswald_option );
            update_option( 'oswald_default_options', $standard_options );
        }

    }
    oswald_extend_def_option();
}

// Social Links
if (!function_exists('oswald_get_social_links')) {
    add_action('woocommerce_single_product_summary', 'oswald_get_social_links', 75);
    function oswald_get_social_links() {
        $share_social = oswald_option('share_social');
        if ($share_social != 1) return;

        $compile = '';
        $share_social_select = oswald_option('share_social_select');
        if (!empty($share_social_select)) {
            foreach ($share_social_select as $wpd_social_data) {
                $links_array[] = oswald_build_share_button($wpd_social_data);
            }
            $compile  = '<div class="product_share">';
            $compile .= '<a href="#">'.esc_html__('SHARE','oswald').'</a>';
            $compile .= '<div class="wpd_social_links">'.implode('', $links_array).'</div>';
            $compile .= '</div>';
        }
        echo ''.$compile;
    }
}

if (!function_exists('oswald_build_share_button')) {
    function oswald_build_share_button($wpd_social_data) {
        $share_social_facebook  = oswald_option('share_social-facebook');
        $share_social_twitter   = oswald_option('share_social-twitter');
        $share_social_pinterest = oswald_option('share_social-pinterest');
        $share_social_google    = oswald_option('share_social-google');
        $share_social_linkedin  = oswald_option('share_social-linkedin');
        $share_social_vk        = oswald_option('share_social-vk');
        $share_social_tumblr    = oswald_option('share_social-tumblr');
        $share_social_mail      = oswald_option('share_social-mail');
        $share_social_reddit    = oswald_option('share_social-reddit');

        $icon_lib = array(
            'facebook'  => 'facebook',
            'twitter'   => 'twitter',
            'pinterest' => 'pinterest',
            'google'    => 'google-plus',
            'linkedin'  => 'linkedin',
            'vk'        => 'vk',
            'tumblr'    => 'tumblr',
            'mail'      => 'envelope',
            'reddit'    => 'reddit',
        );
        $wpd_social_title = array(
            'facebook'  => $share_social_facebook,
            'twitter'   => $share_social_twitter,
            'pinterest' => $share_social_pinterest,
            'google'    => $share_social_google,
            'linkedin'  => $share_social_linkedin,
            'vk'        => $share_social_vk,
            'tumblr'    => $share_social_tumblr,
            'mail'      => $share_social_mail,
            'reddit'    => $share_social_reddit,
        );
        $title = esc_attr($wpd_social_title[$wpd_social_data]);
        $title = !empty($title) || $title !== '' ? '<span>'.$title.'</span>' : '' ;


        return '<a class="wpd_social_icon" data-service="'.esc_attr($wpd_social_data).'" data-postID="'.get_the_ID().'" href="'.oswald_get_social_url($wpd_social_data).'" target="_blank" data-href='.urlencode(esc_url(get_permalink())).'">
                    <i class="fa fa-'.esc_attr($icon_lib[$wpd_social_data]).'"></i>'
                    .$title.
                '</a>';
    }
}

if (!function_exists('oswald_get_social_url')) {
    function oswald_get_social_url($wpd_social_data) {
        global $post;
        $text = urlencode(esc_html__('A great post: ', 'oswald').$post->post_title);
        $escaped_url = urlencode(esc_url(get_permalink()));
        $image = has_post_thumbnail( $post->ID ) ? wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'post-thumbnail' ) : '';

        switch ($wpd_social_data) {
            case 'twitter' :
                $api_link = 'https://twitter.com/intent/tweet?source=webclient&amp;original_referer='.$escaped_url.'&amp;text='.esc_attr($text).'&amp;url='.$escaped_url;
                break;

            case 'facebook' :
                $api_link = 'https://www.facebook.com/sharer.php?u='.$escaped_url;
                break;

            case 'google' :
                $api_link = 'https://plus.google.com/share?url='.$escaped_url;
                break;

            case 'pinterest' :
                if (isset($image) && $image != '') {
                    $api_link = 'http://pinterest.com/pin/create/bookmarklet/?media='.esc_url($image[0]).'&amp;url='.$escaped_url.'&amp;title='.rawurlencode(esc_attr(get_the_title())).'&amp;description='.rawurlencode(esc_html( $post->post_excerpt ));
                }
                else {
                    $api_link = "javascript:void((function(){var%20e=document.createElement('script');e.setAttribute('type','text/javascript');e.setAttribute('charset','UTF-8');e.setAttribute('src','http://assets.pinterest.com/js/pinmarklet.js?r='+Math.random()*99999999);document.body.appendChild(e)})());";
                }
                break;

            case 'tumblr' :
                $api_link = 'https://www.tumblr.com/widgets/share/tool?canonicalUrl='.$escaped_url.'&title='.$text;
                break;

            case 'mail' :
                $subject = esc_html__('Check this!', 'oswald');
                $body = esc_html__('See more at: ', 'oswald');
                $api_link = 'mailto:?subject='.str_replace('&amp;','%26',rawurlencode($subject)).'&body='.str_replace('&amp;','%26',rawurlencode($body).$escaped_url);
                break;

            case 'reddit' :
                $api_link = '//www.reddit.com/submit?url='.$escaped_url;
                break;

            case 'linkedin' :
                $api_link = 'https://www.linkedin.com/shareArticle?mini=true&url='.$escaped_url.'&title='.$text;
                break;

            case 'vk' :
                $api_link = 'http://vk.com/share.php?url='.$escaped_url.'&title='.$text.'&noparse=true';
                break;

        }
        return $api_link; 
    }
}

// template functions
if (!function_exists('wpd_get_template')) {
    function wpd_get_template( $template_name, $args = array(), $template_path = '', $default_path = '' ) {
        if ( ! empty( $args ) && is_array( $args ) ) {
            extract( $args );
        }
        $located = wpd_locate_template( $template_name, $template_path, $default_path );
        if ( ! file_exists( $located ) ) {
            return;
        }
        include $located;
    }
}

if (!function_exists('wpd_locate_template')) {
    function wpd_locate_template( $template_name, $template_path = '', $default_path = '' ) {
        if ( ! $template_path ) {
            $template_path = apply_filters( 'wpd_template_path', 'template-parts/' );
        }

        if ( ! $default_path ) {
            $default_path = untrailingslashit( plugin_dir_path( dirname(__FILE__) ) ) . '/templates/';
        }

        $template = locate_template(
            array(
                trailingslashit( $template_path ) . $template_name,
                $template_name,
            )
        );

        // Get default template/.
        if ( ! $template ) {
            $template = $default_path . $template_name;
        }

        return apply_filters( 'wpd_locate_template', $template, $template_name, $template_path );
    }
}

// end template functions

if (!function_exists('oswald_extend_front_page')) {
    function oswald_extend_front_page(){
        wpd_get_template('frontpage/frontpage.php');
    }
}
add_action( 'oswald_extend_front_page', 'oswald_extend_front_page' );

if (!function_exists('oswald_extend_frontpage_header')) {
    function oswald_extend_frontpage_header(){
        wpd_get_template('frontpage/header/header.php');
    }
    add_action( 'oswald_extend_frontpage_content' , 'oswald_extend_frontpage_header', 5);
}

if (!function_exists('oswald_extend_frontpage_about')) {
    function oswald_extend_frontpage_about(){
        wpd_get_template('frontpage/about/about.php');
    }
    add_action( 'oswald_extend_frontpage_content' , 'oswald_extend_frontpage_about', 10);
}

if (!function_exists('oswald_extend_frontpage_services')) {
    function oswald_extend_frontpage_services(){
        wpd_get_template('frontpage/services/services.php');
    }
    add_action( 'oswald_extend_frontpage_content' , 'oswald_extend_frontpage_services', 15);
}

if (!function_exists('oswald_extend_frontpage_call_to_action')) {
    function oswald_extend_frontpage_call_to_action(){
        wpd_get_template('frontpage/call_to_action/call_to_action.php');
    }
    add_action( 'oswald_extend_frontpage_content' , 'oswald_extend_frontpage_call_to_action', 20);
}

if (!function_exists('oswald_extend_frontpage_team')) {
    function oswald_extend_frontpage_team(){
        wpd_get_template('frontpage/team/team.php');
    }
    add_action( 'oswald_extend_frontpage_content' , 'oswald_extend_frontpage_team', 25);
}

if (!function_exists('oswald_extend_frontpage_testimonial')) {
    function oswald_extend_frontpage_testimonial(){
        wpd_get_template('frontpage/testimonial/testimonial.php');
    }
    add_action( 'oswald_extend_frontpage_content' , 'oswald_extend_frontpage_testimonial', 30);
}

if (!function_exists('oswald_extend_frontpage_blog')) {
    function oswald_extend_frontpage_blog(){
        wpd_get_template('frontpage/blog/blog.php');
    }
    add_action( 'oswald_extend_frontpage_content' , 'oswald_extend_frontpage_blog', 35);
}

if (!function_exists('oswald_extend_frontpage_partners')) {
    function oswald_extend_frontpage_partners(){
        wpd_get_template('frontpage/partners/partners.php');
    }
    add_action( 'oswald_extend_frontpage_content' , 'oswald_extend_frontpage_partners', 40);
}

if (!function_exists('oswald_extend_frontpage_contact')) {
    function oswald_extend_frontpage_contact(){
        wpd_get_template('frontpage/contact/contact.php');
    }
    add_action( 'oswald_extend_frontpage_content' , 'oswald_extend_frontpage_contact', 45);
}