<?php
/*
	Plugin Name: Oswald Lite Extension
	Plugin URI: https://themes.wpdaddy.com/oswald-lite/
	Description: Extension for Oswald Lite Theme
	Version: 1.0.0
	Author: WPDaddy
	Author URI: https://wpdaddy.com/
	Text Domain:  oswald_lite_extension
	Domain Path:  /languages
*/

if(!defined('ABSPATH')) {
	exit;
}

$theme = wp_get_theme();
if ($theme->get('Name') !== 'Oswald' // Name
    && $theme->get('Template') !== 'oswald' // Child Theme
) {
    return;
}

class Oswald_Lite_Extension {
	const NAME = 'Oswald Lite Extension';
	private static $instance = null;

	public static function instance(){
		if(!self::$instance instanceof self) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	private function __construct(){
		add_action('plugins_loaded', array( $this, 'plugins_loaded' ));
	}

	function fail_php_version(){
		$message      = sprintf(esc_html__('%s requires PHP version %s+, plugin is currently NOT ACTIVE.', 'oswald_lite_extension'), self::NAME, '5.3');
		$html_message = sprintf('<div class="error">%s</div>', wpautop($message));
		echo wp_kses_post($html_message);
	}

	public function plugins_loaded(){ 

		if ( in_array( 'oswald-pro-plugin/wpdaddy_core.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
			return;
		}

		if(!function_exists('get_plugin_data')) {
			require_once(ABSPATH.'wp-admin/includes/plugin.php');
		}
		$plugin_info = get_plugin_data(__FILE__);
		define('OSWALD_LITE_EXTENSION', $plugin_info['Version']);

		if(!version_compare(PHP_VERSION, '5.3', '>=')) {
			add_action('admin_notices', array( $this, 'fail_php_version' ));
		}else {
			require_once __DIR__.'/init.php';
			load_plugin_textdomain('oswald_lite_extension', false, __DIR__.'/languages/');
		}
	}
}

if(!function_exists('oswald_lite_extension_version')) {
    function oswald_lite_extension_version() {
        $plugin_data = get_plugin_data( __FILE__ );
        $plugin_version = $plugin_data['Version'];
        return $plugin_version;
    }
}

Oswald_Lite_Extension::instance();